@@ -1,23 +1,12 @@
-/***************************************************************************
- *   KShisen - A japanese game similar to mahjongg                         *
- *   Copyright 1997  Mario Weilguni <mweilguni@sime.com>                   *
- *   Copyright 2002-2004  Dave Corrie <kde@davecorrie.com>                 *
- *   Copyright 2007  Mauricio Piacentini <mauricio@tabuleiro.com>          *
- *   Copyright 2009-2016  Frederik Schwarzer <schwarzer@kde.org>           *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+    KShisen - A japanese game similar to Mahjongg
+    SPDX-FileCopyrightText: 1997 Mario Weilguni <mweilguni@sime.com>
+    SPDX-FileCopyrightText: 2002-2004 Dave Corrie <kde@davecorrie.com>
+    SPDX-FileCopyrightText: 2007 Mauricio Piacentini <mauricio@tabuleiro.com>
+    SPDX-FileCopyrightText: 2009-2016 Frederik Schwarzer <schwarzer@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 // KMahjonggLib integration and SVG support for KDE 4: Mauricio Piacentini <mauricio@tabuleiro.com>
 
@@ -39,8 +28,8 @@
 #include <KgSound>
 
 // LibKMahjongg
-#include <kmahjonggbackground.h>
-#include <kmahjonggtileset.h>
+#include <KMahjonggBackground>
+#include <KMahjonggTileset>
 
 // KShisen
 #include "debug.h"
@@ -67,9 +56,9 @@ public:
     /// Number of different kinds of tiles in the game.
     static int constexpr nTiles = 42;
 
-    void paintEvent(QPaintEvent * e) Q_DECL_OVERRIDE;
-    void mousePressEvent(QMouseEvent * e) Q_DECL_OVERRIDE;
-    void resizeEvent(QResizeEvent * e) Q_DECL_OVERRIDE;
+    void paintEvent(QPaintEvent * e) override;
+    void mousePressEvent(QMouseEvent * e) override;
+    void resizeEvent(QResizeEvent * e) override;
 
     void setDelay(int);
     int delay() const;
@@ -191,7 +180,7 @@ private Q_SLOTS:
     void undrawConnection();
 
 protected:
-    QSize sizeHint() const Q_DECL_OVERRIDE;
+    QSize sizeHint() const override;
 
 private: // functions
     /** Calculates the board's offset.
